Learn R Programming

dual.spls (version 0.1.4)

d.spls.listecal: Determine the number of observations to select from each cell

Description

The function d.spls.listecal detemines the number of observations to select as calibration from each cell.

Usage

d.spls.listecal(Xtype, pcal)

Value

a numeric vector specifying how many observations from each group should be selected as calibration.

Arguments

Xtype

a vector of index specifying to which group belongs each observation.

pcal

a positive integer between 0 and 100. pcal is the percentage of calibration samples to be selected.

Author

Louna Alsouki François Wahl

See Also

d.spls.type,d.spls.calval,d.spls.split