This dataset contains near infra red spectra of refined petroleum samples, associated with the values of their density.
data(d.spls.NIR)A data.frame of 208 observations. The NIR data contains 1557 variables and the density is a one dimensional vector.
The NIR data is composed of 1557 variables that represent a regular sequence of the absorbance interval.
This data is useful when building a Dual-SPLS regression with NIR data as the predictor and density as a response.