The function d.spls.listecal detemines the number of observations to select as calibration from
each cell.
d.spls.listecal(Xtype, pcal)a numeric vector specifying how many observations from each group should be selected as calibration.
a vector of index specifying to which group belongs each observation.
a positive integer between 0 and 100. pcal is the percentage
of calibration samples to be selected.
Louna Alsouki François Wahl
d.spls.type,d.spls.calval,d.spls.split